﻿///<reference path="../typings/globals/core-js/index.d.ts"/>

import { Component, EventEmitter, Input, Inject, enableProdMode, NgModule } from '@angular/core';
import { FormsModule } from '@angular/forms';
import { CommonModule } from '@angular/common';
import { platformBrowserDynamic } from '@angular/platform-browser-dynamic';
import { BrowserModule } from '@angular/platform-browser';
import { WjGridModule } from 'wijmo/wijmo.angular2.grid';
import { WjInputModule } from 'wijmo/wijmo.angular2.input';
import { WjGridFilterModule } from 'wijmo/wijmo.angular2.grid.filter';
import * as wjCore from 'wijmo/wijmo';
import * as wjGrid from 'wijmo/wijmo.grid';

import { DataSvc } from './services/DataSvc';

'use strict';

// The application root component.
@Component({
    selector: 'app-cmp',
    templateUrl: '../src/AppCmp.html',
})
export class AppCmp {
    
    protected dataSvc: DataSvc;
    data: wjCore.CollectionView;
    //private
    private _filter = '';
    private _toFilter: any;
    public filteredData: wjCore.CollectionView = new wjCore.CollectionView(); // later on global filter changing, sourceCollection need to change; 
    constructor( @Inject(DataSvc) dataSvc: DataSvc) {
        this.dataSvc = dataSvc;
        this.data = new wjCore.CollectionView(this.dataSvc.getData(100));
        this.data.filter = this._filterFunction.bind(this);
        this.data.collectionChanged.addHandler((s: wjCore.CollectionView) => {
            //collectionChanged on global filter change
            this.filteredData.sourceCollection = s.items;
        });
    }
    initFlex(s: wjGrid.FlexGrid, e: wjCore.EventArgs) {
        // load data on FlexGrid initialization
        this.filteredData.sourceCollection = this.data.items;
    }
    get filter(): string {
        return this._filter;
    }
    set filter(value: string) {
        if (this._filter != value) {
            this._filter = value;
            if (this._toFilter) {
                clearTimeout(this._toFilter);
            }
            var self = this;
            this._toFilter = setTimeout(function () {
                self.data.refresh();
            }, 500);
        }
    }

    private _filterFunction(item: any) {
        if (this._filter) {
            return item.country.toLowerCase().indexOf(this._filter.toLowerCase()) > -1;
        }
        return true;
    }
}

@NgModule({
    imports: [WjInputModule, WjGridModule, BrowserModule, WjGridFilterModule, FormsModule],
    declarations: [AppCmp],
    providers: [DataSvc],
    bootstrap: [AppCmp]
})
export class AppModule {
}

enableProdMode();
platformBrowserDynamic().bootstrapModule(AppModule);
