﻿import {
    Component, Inject, Injector, NgModule, ElementRef,
    SkipSelf, Optional, forwardRef, ChangeDetectorRef,
    EventEmitter
} from '@angular/core';
import { BrowserModule } from '@angular/platform-browser';
import { FormsModule, NG_VALUE_ACCESSOR } from '@angular/forms';
import { WjValueAccessorFactory } from 'wijmo/wijmo.angular2.directiveBase';
import {
    WjGridModule, WjFlexGrid, wjFlexGridMeta,
    WjFlexGridColumn, wjFlexGridColumnMeta
} from 'wijmo/wijmo.angular2.grid';


@Component({
    selector: 'my-grid',
    template: wjFlexGridMeta.template,
    inputs: [...wjFlexGridMeta.inputs, 'myProperty'],
    outputs: [...wjFlexGridMeta.outputs, 'myPropertyChange'],
    providers: [
        { provide: 'WjComponent', useExisting: forwardRef(() => MyGrid) },
        ...wjFlexGridMeta.providers
    ]
})
export class MyGrid extends WjFlexGrid {
    private _myProperty: string;
    myPropertyChange = new EventEmitter(false);

    get myProperty(): string {
        return this._myProperty;
    }
    set myProperty(value: string) {
        if (this._myProperty !== value) {
            this._myProperty = value;
            this.myPropertyChange.emit(value);
        }
    }
}


@Component({
    selector: 'my-column',
    template: wjFlexGridColumnMeta.template,
    inputs: wjFlexGridColumnMeta.inputs,
    outputs: wjFlexGridColumnMeta.outputs,
    providers: [
        { provide: 'WjComponent', useExisting: forwardRef(() => MyColumn) },
        ...wjFlexGridColumnMeta.providers
    ]
})
export class MyColumn extends WjFlexGridColumn {
}


@NgModule({
    imports: [WjGridModule, BrowserModule, FormsModule],
    declarations: [MyGrid, MyColumn],
    exports: [MyGrid, MyColumn]
})
export class MyGridModule {
}

